@@ -19,6 +19,7 @@
  */
 
 #include "gtkhtml-editor-private.h"
+#include "gtkhtml-stream.h"
 
 /******************************************************************************
  * Action Group Quick Reference
@@ -173,7 +174,7 @@ insert_html_file_ready_cb (GFile *file,
 	stream = gtk_html_begin (new_html);
 	gtk_html_write (html, stream, contents, length);
 	gtk_html_end (html, stream, GTK_HTML_STREAM_OK);
-	g_object_unref (stream);
+	gtk_html_stream_destroy (stream);
 
 	g_free (contents);
 
@@ -614,6 +615,10 @@ action_insert_html_file_cb (GtkToggleAction *action,
 	file = gtkhtml_editor_run_open_dialog (
 		editor, _("Insert HTML File"), NULL, NULL);
 
+	/* User cancelled? */
+	if (file == NULL)
+		return;
+
 	/* XXX Need a way to cancel this. */
 	g_file_load_contents_async (
 		file, NULL, (GAsyncReadyCallback)
@@ -679,6 +684,10 @@ action_insert_text_file_cb (GtkAction *action,
 	file = gtkhtml_editor_run_open_dialog (
 		editor, _("Insert Text File"), NULL, NULL);
 
+	/* User cancelled? */
+	if (file == NULL)
+		return;
+
 	/* XXX Need a way to cancel this. */
 	g_file_load_contents_async (
 		file, NULL, (GAsyncReadyCallback)
@@ -1550,8 +1559,10 @@ static GtkActionEntry html_entries[] = {
 
 	{ "insert-rule",
 	  "stock_insert-rule",
+	  /* Translators: 'Rule' here means a horizontal line in an HTML text */
 	  N_("_Rule..."),
 	  NULL,
+	  /* Translators: 'Rule' here means a horizontal line in an HTML text */
 	  N_("Insert Rule"),
 	  G_CALLBACK (action_insert_rule_cb) },
 
@@ -1592,6 +1603,7 @@ static GtkActionEntry html_entries[] = {
 
 	{ "properties-rule",
 	  NULL,
+	  /* Translators: 'Rule' here means a horizontal line in an HTML text */
 	  N_("_Rule..."),
 	  NULL,
 	  NULL,
@@ -1668,6 +1680,7 @@ static GtkRadioActionEntry html_size_entries[] = {
 
 	{ "size-minus-two",
 	  NULL,
+	  /* Translators: This is a font size level. It is shown on a tool bar. Please keep it as short as possible. */
 	  N_("-2"),
 	  NULL,
 	  NULL,
@@ -1675,6 +1688,7 @@ static GtkRadioActionEntry html_size_entries[] = {
 
 	{ "size-minus-one",
 	  NULL,
+	  /* Translators: This is a font size level. It is shown on a tool bar. Please keep it as short as possible. */
 	  N_("-1"),
 	  NULL,
 	  NULL,
@@ -1682,6 +1696,7 @@ static GtkRadioActionEntry html_size_entries[] = {
 
 	{ "size-plus-zero",
 	  NULL,
+	  /* Translators: This is a font size level. It is shown on a tool bar. Please keep it as short as possible. */
 	  N_("+0"),
 	  NULL,
 	  NULL,
@@ -1689,6 +1704,7 @@ static GtkRadioActionEntry html_size_entries[] = {
 
 	{ "size-plus-one",
 	  NULL,
+	  /* Translators: This is a font size level. It is shown on a tool bar. Please keep it as short as possible. */
 	  N_("+1"),
 	  NULL,
 	  NULL,
@@ -1696,6 +1712,7 @@ static GtkRadioActionEntry html_size_entries[] = {
 
 	{ "size-plus-two",
 	  NULL,
+	  /* Translators: This is a font size level. It is shown on a tool bar. Please keep it as short as possible. */
 	  N_("+2"),
 	  NULL,
 	  NULL,
@@ -1703,6 +1720,7 @@ static GtkRadioActionEntry html_size_entries[] = {
 
 	{ "size-plus-three",
 	  NULL,
+	  /* Translators: This is a font size level. It is shown on a tool bar. Please keep it as short as possible. */
 	  N_("+3"),
 	  NULL,
 	  NULL,
@@ -1710,6 +1728,7 @@ static GtkRadioActionEntry html_size_entries[] = {
 
 	{ "size-plus-four",
 	  NULL,
+	  /* Translators: This is a font size level. It is shown on a tool bar. Please keep it as short as possible. */
 	  N_("+4"),
 	  NULL,
 	  NULL,
@@ -1759,6 +1778,7 @@ static GtkActionEntry context_entries[] = {
 
 	{ "context-delete-table-menu",
 	  NULL,
+	  /* Translators: Popup menu item caption, containing all the Delete options for a table */
 	  N_("Table Delete"),
 	  NULL,
 	  NULL,
@@ -1773,6 +1793,7 @@ static GtkActionEntry context_entries[] = {
 
 	{ "context-insert-table-menu",
 	  NULL,
+	  /* Translators: Popup menu item caption, containing all the Insert options for a table */
 	  N_("Table Insert"),
 	  NULL,
 	  NULL,
@@ -1875,6 +1896,7 @@ static GtkActionEntry html_context_entries[] = {
 
 	{ "context-properties-rule",
 	  NULL,
+	  /* Translators: 'Rule' here means a horizontal line in an HTML text */
 	  N_("Rule..."),
 	  NULL,
 	  NULL,
@@ -2034,8 +2056,10 @@ editor_actions_setup_spell_check_menu (GtkhtmlEditor *editor)
 
 		/* Add an item to the "Add Word To" menu. */
 
-		action_label = g_strdup_printf ("%s Dictionary", name);
 		action_name = g_strdup_printf ("context-spell-add-%s", code);
+		/* Translators: %s will be replaced with the actual dictionary name,
+		   where a user can add a word to. This is part of an "Add Word To" submenu. */
+		action_label = g_strdup_printf (_("%s Dictionary"), name);
 
 		action = gtk_action_new (
 			action_name, action_label, NULL, NULL);
@@ -2177,6 +2201,7 @@ gtkhtml_editor_actions_init (GtkhtmlEditor *editor)
 		"short-label", _("_Link"), NULL);
 	g_object_set (
 		G_OBJECT (ACTION (INSERT_RULE)),
+		/* Translators: 'Rule' here means a horizontal line in an HTML text */
 		"short-label", _("_Rule"), NULL);
 	g_object_set (
 		G_OBJECT (ACTION (INSERT_TABLE)),
